<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
	<div id="nav-above" class="navigation group">
		<div class="nav-previous"><?php next_posts_link( __( '&lt; Older posts', 'sp' ) ); ?></div>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts &gt;', 'sp' ) ); ?></div>
	</div><!-- #nav-above -->
<?php endif; ?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<div id="post-0" class="post error404 not-found">
		<h1 class="entry-title"><?php _e( 'Not Found', 'sp' ); ?></h1>
		<div class="entry-content">
			<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'sp' ); ?></p>
			<?php get_search_form(); ?>
		</div><!-- .entry-content -->
	</div><!-- #post-0 -->
<?php endif; ?>

<?php while ( have_posts() ) : the_post(); ?>

<?php /* How to display posts in the Gallery category. */ ?>

	<?php if ( in_category( _x('gallery', 'gallery category slug', 'sp') ) ) : ?>
		<div id="post-<?php the_ID(); ?>" <?php post_class('group'); ?>>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'sp' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>

			<div class="entry-meta">
				<?php sp_posted_on(); ?>
			</div><!-- .entry-meta -->

			<div class="entry-content">
<?php if ( post_password_required() ) : ?>
				<?php the_content(); ?>
<?php else : ?>			
				<?php 
					$images = get_children( array( 'post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image', 'orderby' => 'menu_order', 'order' => 'ASC', 'numberposts' => 999 ) );
					if ( $images ) :
						$total_images = count( $images );
						$image = array_shift( $images );
						$image_img_tag = wp_get_attachment_image( $image->ID, 'thumbnail' );
				?>
						<div class="gallery-thumb">
							<a class="size-thumbnail" href="<?php the_permalink(); ?>"><?php echo $image_img_tag; ?></a>
						</div><!-- .gallery-thumb -->
						<p><em><?php printf( __( 'This gallery contains <a %1$s>%2$s photos</a>.', 'sp' ),
								'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink to %s', 'sp' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"',
								$total_images
							); ?></em></p>
				<?php endif; ?>
						<?php the_excerpt(); ?>
<?php endif; ?>
			</div><!-- .entry-content -->

			<div class="entry-utility">
				<a href="<?php echo get_term_link( _x('gallery', 'gallery category slug', 'sp'), 'category' ); ?>" title="<?php esc_attr_e( 'View posts in the Gallery category', 'sp' ); ?>"><?php _e( 'More Galleries', 'sp' ); ?></a>
				<span class="meta-sep">|</span>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sp' ), __( '1 Comment', 'sp' ), __( '% Comments', 'sp' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sp' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</div><!-- #post-## -->

<?php /* How to display posts in the asides category */ ?>

	<?php elseif ( in_category( _x('asides', 'asides category slug', 'sp') ) ) : ?>
		<div id="post-<?php the_ID(); ?>" <?php post_class('group'); ?>>

		<?php if ( is_archive() || is_search() ) : // Display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
		<?php else : ?>
			<div class="entry-content">
				<?php the_content( __( 'Read More &gt;', 'sp' ) ); ?>
			</div><!-- .entry-content -->
		<?php endif; ?>

			<div class="entry-utility">
				<?php sp_posted_on(); ?>
				<span class="meta-sep">|</span>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sp' ), __( '1 Comment', 'sp' ), __( '% Comments', 'sp' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sp' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</div><!-- #post-## -->

<?php /* How to display all other posts. */ ?>

	<?php else : ?>
    	<?php 
		global $data;
		$image_width = get_option('thumbnail_size_w');
		$image_height = get_option('thumbnail_size_h');
		$blog_list_crop = $data[THEME_SHORTNAME.'blog_list_crop'];
		$blog_list_zoomcrop = $data[THEME_SHORTNAME.'blog_list_zoomcrop'];
		$blog_list_compression = $data[THEME_SHORTNAME.'blog_list_compression'];
		?>
    
		<div id="post-<?php the_ID(); ?>" <?php post_class('group search'); ?>>
        <div class="header-meta">
        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
            <?php if (get_post_type() == 'wpsc-product') { ?>
            <?php $post_image_url = sp_wpsc_the_product_image($post->ID); ?>
			<img width="<?php echo $image_width; ?>" height="<?php echo $image_height; ?>" class="wp-post-image" alt="<?php echo the_title(); ?>" src="<?php echo bloginfo('template_url');?>/sp-framework/timthumb/timthumb.php?src=<?php echo $post_image_url; ?>&amp;h=<?php echo $image_height; ?>&amp;w=<?php echo $image_width; ?>&amp;zc=<?php echo $blog_list_zoomcrop; ?>&amp;q=<?php echo $blog_list_compression; ?>&amp;a=<?php echo $blog_list_crop; ?>" />	
			
			<?php } else { ?>
			
			<?php  $post_image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full'); ?>
			<img width="<?php echo $image_width; ?>" height="<?php echo $image_height; ?>" class="wp-post-image" alt="<?php echo the_title(); ?>" src="<?php echo bloginfo('template_url');?>/sp-framework/timthumb/timthumb.php?src=<?php echo $post_image_url[0]; ?>&amp;h=<?php echo $image_height; ?>&amp;w=<?php echo $image_width; ?>&amp;zc=<?php echo $blog_list_zoomcrop; ?>&amp;q=<?php echo $blog_list_compression; ?>&amp;a=<?php echo $blog_list_crop; ?>" />	
            <?php } ?>
		
        </a>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'sp' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
			<?php if (get_post_type() != 'wpsc-product') { ?>
			<div class="entry-meta">
                <div class="date_label">
                    <span class="month"><?php the_time('M'); ?></span>
                    <span class="date"><?php the_time('d'); ?></span>
                    <span class="year"><?php the_time('Y'); ?></span>
                </div><!--close date-->
                <p class="byauthor">by <?php the_author(); ?></p>
			</div><!-- .entry-meta -->
            <?php } ?>
			</div><!--close header-meta-->
	<?php if ( is_archive() || is_search() ) : // Only display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
	<?php else : ?>
			<div class="entry-content">
				<?php the_content( __( 'Read More &gt;', 'sp' ) ); ?>
				<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'sp' ), 'after' => '</div>' ) ); ?>
			</div><!-- .entry-content -->
	<?php endif; ?>

			<div class="entry-utility">
				<?php if ( count( get_the_category() ) ) : ?>
					<span class="cat-links">
						<?php printf( __( '<span class="article-icon">&nbsp;</span><span class="%1$s">Posted in</span> %2$s', 'sp' ), 'entry-utility-prep entry-utility-prep-cat-links', get_the_category_list( ', ' ) ); ?>
					</span>
					<span class="meta-sep">|</span>
				<?php endif; ?>
				<?php
					$tags_list = get_the_tag_list( '', ', ' );
					if ( $tags_list ):
				?>
					<span class="tag-links">
						<?php printf( __( '<span class="tag-icon">&nbsp;</span><span class="%1$s">Tagged</span> %2$s', 'sp' ), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list ); ?>
					</span>
					<span class="meta-sep">|</span>
				<?php endif; ?>
				<span class="comments-link"><span class="comment-icon">&nbsp;</span><?php comments_popup_link( __( 'Leave a comment', 'sp' ), __( '1 Comment', 'sp' ), __( '% Comments', 'sp' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sp' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</div><!-- #post-## -->
		<?php comments_template( '', true ); ?>

	<?php endif; // This was the if statement that broke the loop into three parts based on categories. ?>

<?php endwhile; // End the loop. Whew. ?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if (  $wp_query->max_num_pages > 1 ) : ?>
				<div id="nav-below" class="navigation group">
					<div class="nav-previous"><?php next_posts_link( __( '&lt; Older posts', 'sp' ) ); ?></div>
					<div class="nav-next"><?php previous_posts_link( __( 'Newer posts &gt;', 'sp' ) ); ?></div>
				</div><!-- #nav-below -->
<?php endif; ?>
